==> open-xchange-gui_6.12.0.0.orig.tar.gz: open-xchange-gui-6.12.0.0/js/mail/mailcore.js <==
function createNewContactfromMail(mailAddressObject,folder) {
	function createContact(module,notneeded,object) {
		var addParams = "";
		for (i in object) {
			addParams += "&"+i+"="+encodeURIComponent(object[i]);
		}
		corewindow.openContactPopup('modul=new&folder='+object.folder_id+addParams,'newContact.html');
	}
    corewindow.rightshandler.checkRights("contacts",(folder || configGetKey("folder.contacts")),mailAddressObject,createContact);
}

/**
 * Parse all <a> links within the node and replace any direct link which maches
 * to the current hostname with a new link to the local infostore.
 * @param ih The document node
 */
var hrefregexp = null;
function parseDirectLinksInMails(ih) {
    hrefregexp = hrefregexp || new RegExp((window.location.protocol+"//"+window.location.host).replace(/^https?:/, "https?:"));
	var ahref = ih.getElementsByTagName("a");
	for (var i=0; i < ahref.length;) {
		var link = ahref[i];		
		if (!link.getAttribute("href")) {
			// no valid href, continue
			i++; 
			continue;
		}
        link.removeAttribute("target");  // clean-up target first
        var module = link.href.match(/[#&]m=([^#&]+)/);
        var folder = link.href.match(/[#&]f=([^#&]+)/);
        var id = link.href.match(/[#&]i=([^#&]+)/);      
        if (link.href.match(hrefregexp) && module && folder) {
           	// ok, seems like we found a direct link pointing to the right ox 
            link.parentNode.insertBefore(newnode("img", { marginRight: "5px"}, { src: getFullImgSrc("img/menu/close_linking.gif"), align: "absmiddle"}, null, (ih.nodeType == 9 ? ih : null)), link);
            link.style.color="red";
            link.style.textDecoration="underline";
            link.style.cursor="pointer";
            link.removeAttribute("href")
            link.onclick = (function(mo, fo, io) {
	   			     return function(e) { 
	   				     parent.corewindow.setTimeout(
	   				         function() { 
	   				            parent.corewindow.triggerEvent("OX_Direct_Linking", mo, {"folder": fo, "id": io}) 
	   				         }, 0);
	   				     if (e) {
	   				     	stopEvent(e);
	   				     }
	   				     return false;
	   			     }
			     })(module[1], folder[1], id && id[1] ? id[1] : null);  
			              
        } else if (link.getAttribute("href").match(new RegExp("^(" + window.location.href + ")?#")) != null) {
            // due to an mozilla bug we run into problems with anchors in dynamic written pages 
            // mozilla doesn't recognize that and try to load the whole page instead
            // using this hack to jump to the anchors manually
            for (var ia=0; ia < ih.anchors.length; ia++) {
                if (link.getAttribute("href").match(new RegExp("^(" + window.location.href + ")?#"+ih.anchors[ia].name))) {
                	link.setAttribute("onclick", "function() { return false; }");                    
                    link.onclick = (function(myDoc, myAnchor) {
                        return function(e) {
                             myAnchor.scrollIntoView(true);
                             return false;
                        }
                    })(ih, ih.anchors[ia]);
                    break;
                }
            }
        } else {
        	// any other links should always open in a new window
        	link.target = "_blank";
        }
      i++;
	}
	return ih;
}

function getMailAccountIdByFolder(folder) {
	var addr = null;
	if (String(folder).match(/^default(\d+)?/).length) {
		var t = String(folder).match(/^default(\d+)?/)[0];
		addr = t.substring("default".length, t.length);
	}
	return addr;
}

function getMailAccountEmailAddress(id) {
	var addr = null;
	if (corewindow.mail_accounts && corewindow.mail_accounts.data.data[id]) {
		return corewindow.mail_accounts.data.data[id].primary_address;
	}
	return addr;
}

fileloaded();

==> open-xchange-gui_6.16.1.0.orig.tar.gz: open-xchange-gui-6.16.1.0/js/mail/mailcore.js <==
function createNewContactfromMail(mailAddressObject,folder) {
	function createContact(module,notneeded,object) {
		var addParams = "";
		for (i in object) {
			addParams += "&"+i+"="+encodeURIComponent(object[i]);
		}
		corewindow.openContactPopup('modul=new&folder='+object.folder_id+addParams,'newContact.html');
	}
    corewindow.rightshandler.checkRights("contacts",(folder || configGetKey("folder.contacts")),mailAddressObject,createContact);
}

/**
 * Parse all <a> links within the node and replace any direct link which maches
 * to the current hostname with a new link to the local infostore.
 * @param ih The document node
 */
var hrefregexp = null;
function parseDirectLinksInMails(ih) {
    hrefregexp = hrefregexp || new RegExp((window.location.protocol+"//"+window.location.host).replace(/^https?:/, "https?:"));
	var ahref = ih.getElementsByTagName("a");
	for (var i=0; i < ahref.length;) {
		var link = ahref[i];		
		if (!link.getAttribute("href")) {
			// no valid href, continue
			i++; 
			continue;
		}
        link.removeAttribute("target");  // clean-up target first
        var module = link.href.match(/[#&]m=([^#&]+)/);
        var folder = link.href.match(/[#&]f=([^#&]+)/);
        var id = link.href.match(/[#&]i=([^#&]+)/);      
        if (link.href.match(hrefregexp) && module && folder) {
           	// ok, seems like we found a direct link pointing to the right ox 
            link.parentNode.insertBefore(newnode("img", { marginRight: "5px"}, { src: getFullImgSrc("img/menu/close_linking.gif"), align: "absmiddle"}, null, (ih.nodeType == 9 ? ih : null)), link);
            link.style.color="red";
            link.style.textDecoration="underline";
            link.style.cursor="pointer";
            link.removeAttribute("href")
            link.onclick = (function(mo, fo, io) {
	   			     return function(e) { 
	   				     parent.corewindow.setTimeout(
	   				         function() { 
	   				            parent.corewindow.triggerEvent("OX_Direct_Linking", mo, {"folder": fo, "id": io}) 
	   				         }, 0);
	   				     if (e) {
	   				     	stopEvent(e);
	   				     }
	   				     return false;
	   			     }
			     })(module[1], folder[1], id && id[1] ? id[1] : null);  
			              
        } else if (link.getAttribute("href").match(new RegExp("^(" + window.location.href + ")?#")) != null) {
            // due to an mozilla bug we run into problems with anchors in dynamic written pages 
            // mozilla doesn't recognize that and try to load the whole page instead
            // using this hack to jump to the anchors manually
            for (var ia=0; ia < ih.anchors.length; ia++) {
                if (link.getAttribute("href").match(new RegExp("^(" + window.location.href + ")?#"+ih.anchors[ia].name))) {
                	link.setAttribute("onclick", "function() { return false; }");                    
                    link.onclick = (function(myDoc, myAnchor) {
                        return function(e) {
                             myAnchor.scrollIntoView(true);
                             return false;
                        }
                    })(ih, ih.anchors[ia]);
                    break;
                }
            }
        } else {
        	// any other links should always open in a new window
        	link.target = "_blank";
        }
      i++;
	}
	return ih;
}

function getMailAccountIdByFolder(folder) {	
	var addr = null;
	if (String(folder).match(/^default(\d+)?/) != null) {
		var t = String(folder).match(/^default(\d+)?/)[0];
		addr = t.substring("default".length, t.length);
	}
	return addr;
}

function getMailAccountEmailAddress(id) {
	var addr = null;
	if (corewindow.mail_accounts && corewindow.mail_accounts.data.data[id]) {
		return corewindow.mail_accounts.data.data[id].primary_address;
	}
	return addr;
}

fileloaded();
